==> dh_picker-0.0.1.tar.gz: lib/src/res/strings.dart <==
final i18nModel = {
  // 英语
  'en': {
    'cancel': 'Cancel',
    'done': 'Done',
    'monthShort': [
      'Jan',
      'Feb',
      'Mar',
      'Apr',
      'May',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Oct',
      'Nov',
      'Dec'
    ],
    'monthLong': [
      'January',
      'February',
      'March',
      'April',
      'May',
      'June',
      'July',
      'August',
      'September',
      'October',
      'November',
      'December'
    ],
    'day': ['Mon', 'Tue', 'Wed', 'Thur', 'Fri', 'Sat', 'Sun'],
  },
  // 中文
  'zh': {
    'cancel': '取消',
    'done': '确定',
    'today': '今天',
    'monthShort': [
      '一月',
      '二月',
      '三月',
      '四月',
      '五月',
      '六月',
      '七月',
      '八月',
      '九月',
      '十月',
      '十一月',
      '十二月'
    ],
    'monthLong': [
      '一月',
      '二月',
      '三月',
      '四月',
      '五月',
      '六月',
      '七月',
      '八月',
      '九月',
      '十月',
      '十一月',
      '十二月'
    ],
    'day': ['星期一', '星期二', '星期三', '星期四', '星期五', '星期六', '星期日'],
  },
  // 俄语
  'ru': {
    'cancel': 'Отмена',
    'done': 'Готово',
    'monthShort': [
      'Янв',
      'Фев',
      'Март',
      'Апр',
      'Май',
      'Июнь',
      'Июль',
      'Авг',
      'Сен',
      'Окт',
      'Ноя',
      'Дек'
    ],
    'monthLong': [
      'Январь',
      'Февраль',
      'Март',
      'Апрель',
      'Май',
      'Июнь',
      'Июль',
      'Август',
      'Сентябрь',
      'Октябрь',
      'Ноябрь',
      'Декабрь'
    ],
    'day': ['Пн', 'Вт', 'Ср', 'Чт', 'Пт', 'Сб', 'Вс'],
  },
  // 法语
  'fr': {
    'cancel': 'Annuler',
    'done': 'Confirmer',
    'monthShort': [
      'Jan',
      'Fév',
      'Mar',
      'Avr',
      'Mai',
      'Juin',
      'Juil',
      'Aoû',
      'Sep',
      'Oct',
      'Nov',
      'Déc'
    ],
    'monthLong': [
      'Janvier',
      'Février',
      'Mars',
      'Avril',
      'Mai',
      'Juin',
      'Juillet',
      'Août',
      'Septembre',
      'Octobre',
      'Novembre',
      'Décembre'
    ],
    'day': ['Lun', 'Mar', 'Mer', 'Jeu', 'Ven', 'Sam', 'Dim'],
  },
  // 西班牙
  'es': {
    'cancel': 'Cancelar',
    'done': 'Confirmar',
    'monthShort': [
      'Ene',
      'Feb',
      'Mar',
      'Abr',
      'May',
      'Jun',
      'Jul',
      'Ago',
      'Sep',
      'Oct',
      'Nov',
      'Dic'
    ],
    'monthLong': [
      'Enero',
      'Febrero',
      'Marzo',
      'Abril',
      'Mayo',
      'Junio',
      'Julio',
      'Agosto',
      'Septiembre',
      'Octubre',
      'Noviembre',
      'Diciembre'
    ],
    'day': ['Lun', 'Mar', 'Mié', 'Jue', 'Vie', 'Sáb', 'Dom'],
  },
  // 韩语
  'ko': {
    'cancel': '취소',
    'done': '완료',
    'monthShort': [
      '1월',
      '2월',
      '3월',
      '4월',
      '5월',
      '6월',
      '7월',
      '8월',
      '9월',
      '10월',
      '11월',
      '12월'
    ],
    'monthLong': [
      '1월',
      '2월',
      '3월',
      '4월',
      '5월',
      '6월',
      '7월',
      '8월',
      '9월',
      '10월',
      '11월',
      '12월'
    ],
    'day': ['월', '화', '수', '목', '금', '토', '일'],
  },
  // 日语
  'ja': {
    //Japanese
    'cancel': 'キャンセル',
    'done': '完了',
    'monthShort': [
      '1月',
      '2月',
      '3月',
      '4月',
      '5月',
      '6月',
      '7月',
      '8月',
      '9月',
      '10月',
      '11月',
      '12月'
    ],
    'monthLong': [
      '1月',
      '2月',
      '3月',
      '4月',
      '5月',
      '6月',
      '7月',
      '8月',
      '9月',
      '10月',
      '11月',
      '12月'
    ],
    'day': ['月曜日', '火曜日', '水曜日', '木曜日', '金曜日', '土曜日', '日曜日'],
  },
  // 德语
  'de': {
    //German
    'cancel': 'Abbrechen',
    'done': 'OK',
    'monthShort': [
      'Jan',
      'Feb',
      'Mrz',
      'Apr',
      'Mai',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Okt',
      'Nov',
      'Dez'
    ],
    'monthLong': [
      'Januar',
      'Februar',
      'März',
      'April',
      'Mai',
      'Juni',
      'Juli',
      'August',
      'September',
      'Oktober',
      'November',
      'Dezember'
    ],
    'day': ['Mo', 'Di', 'Mi', 'Do', 'Fr', 'Sa', 'So'],
  }
};

Map<String, dynamic> i18nObjInLanguage(String language) =>
    i18nModel[language] ?? i18nModel['en'];

String i18nObjInLanguageLookup(String language, String key, int index){
  final i18n = i18nObjInLanguage(language);
  final i18nKey = i18n[key] as List<String>;
  return i18nKey[index];
}

==> dh_picker-0.0.3.tar.gz: lib/src/res/strings.dart <==
final i18nModel = {
  // 英语
  'en': {
    'cancel': 'Cancel',
    'done': 'Done',
    'monthShort': [
      'Jan',
      'Feb',
      'Mar',
      'Apr',
      'May',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Oct',
      'Nov',
      'Dec'
    ],
    'monthLong': [
      'January',
      'February',
      'March',
      'April',
      'May',
      'June',
      'July',
      'August',
      'September',
      'October',
      'November',
      'December'
    ],
    'day': ['Mon', 'Tue', 'Wed', 'Thur', 'Fri', 'Sat', 'Sun'],
    'hour': 'h',
    'minute': 'min',
    'second': 's'
  },
  // 中文
  'zh': {
    'cancel': '取消',
    'done': '确定',
    'today': '今天',
    'monthShort': [
      '一月',
      '二月',
      '三月',
      '四月',
      '五月',
      '六月',
      '七月',
      '八月',
      '九月',
      '十月',
      '十一月',
      '十二月'
    ],
    'monthLong': [
      '一月',
      '二月',
      '三月',
      '四月',
      '五月',
      '六月',
      '七月',
      '八月',
      '九月',
      '十月',
      '十一月',
      '十二月'
    ],
    'day': ['星期一', '星期二', '星期三', '星期四', '星期五', '星期六', '星期日'],
    'hour': '时',
    'minute': '分',
    'second': '秒'
  },
  // 俄语
  'ru': {
    'cancel': 'Отмена',
    'done': 'Готово',
    'monthShort': [
      'Янв',
      'Фев',
      'Март',
      'Апр',
      'Май',
      'Июнь',
      'Июль',
      'Авг',
      'Сен',
      'Окт',
      'Ноя',
      'Дек'
    ],
    'monthLong': [
      'Январь',
      'Февраль',
      'Март',
      'Апрель',
      'Май',
      'Июнь',
      'Июль',
      'Август',
      'Сентябрь',
      'Октябрь',
      'Ноябрь',
      'Декабрь'
    ],
    'day': ['Пн', 'Вт', 'Ср', 'Чт', 'Пт', 'Сб', 'Вс'],
    'hour': 'Ч',
    'minute': 'М',
    'second': 'с'
  },
  // 法语
  'fr': {
    'cancel': 'Annuler',
    'done': 'Confirmer',
    'monthShort': [
      'Jan',
      'Fév',
      'Mar',
      'Avr',
      'Mai',
      'Juin',
      'Juil',
      'Aoû',
      'Sep',
      'Oct',
      'Nov',
      'Déc'
    ],
    'monthLong': [
      'Janvier',
      'Février',
      'Mars',
      'Avril',
      'Mai',
      'Juin',
      'Juillet',
      'Août',
      'Septembre',
      'Octobre',
      'Novembre',
      'Décembre'
    ],
    'day': ['Lun', 'Mar', 'Mer', 'Jeu', 'Ven', 'Sam', 'Dim'],
    'hour': 'h',
    'minute': 'm',
    'second': 's'
  },
  // 西班牙
  'es': {
    'cancel': 'Cancelar',
    'done': 'Confirmar',
    'monthShort': [
      'Ene',
      'Feb',
      'Mar',
      'Abr',
      'May',
      'Jun',
      'Jul',
      'Ago',
      'Sep',
      'Oct',
      'Nov',
      'Dic'
    ],
    'monthLong': [
      'Enero',
      'Febrero',
      'Marzo',
      'Abril',
      'Mayo',
      'Junio',
      'Julio',
      'Agosto',
      'Septiembre',
      'Octubre',
      'Noviembre',
      'Diciembre'
    ],
    'day': ['Lun', 'Mar', 'Mié', 'Jue', 'Vie', 'Sáb', 'Dom'],
    'hour': 'h',
    'minute': 'm',
    'second': 's'
  },
  // 韩语
  'ko': {
    'cancel': '취소',
    'done': '완료',
    'monthShort': [
      '1월',
      '2월',
      '3월',
      '4월',
      '5월',
      '6월',
      '7월',
      '8월',
      '9월',
      '10월',
      '11월',
      '12월'
    ],
    'monthLong': [
      '1월',
      '2월',
      '3월',
      '4월',
      '5월',
      '6월',
      '7월',
      '8월',
      '9월',
      '10월',
      '11월',
      '12월'
    ],
    'day': ['월', '화', '수', '목', '금', '토', '일'],
    'hour': '시',
    'minute': '분',
    'second': '초'
  },
  // 日语
  'ja': {
    //Japanese
    'cancel': 'キャンセル',
    'done': '完了',
    'monthShort': [
      '1月',
      '2月',
      '3月',
      '4月',
      '5月',
      '6月',
      '7月',
      '8月',
      '9月',
      '10月',
      '11月',
      '12月'
    ],
    'monthLong': [
      '1月',
      '2月',
      '3月',
      '4月',
      '5月',
      '6月',
      '7月',
      '8月',
      '9月',
      '10月',
      '11月',
      '12月'
    ],
    'day': ['月曜日', '火曜日', '水曜日', '木曜日', '金曜日', '土曜日', '日曜日'],
    'hour': '時間',
    'minute': '分',
    'second': '秒'
  },
  // 德语
  'de': {
    //German
    'cancel': 'Abbrechen',
    'done': 'OK',
    'monthShort': [
      'Jan',
      'Feb',
      'Mrz',
      'Apr',
      'Mai',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Okt',
      'Nov',
      'Dez'
    ],
    'monthLong': [
      'Januar',
      'Februar',
      'März',
      'April',
      'Mai',
      'Juni',
      'Juli',
      'August',
      'September',
      'Oktober',
      'November',
      'Dezember'
    ],
    'day': ['Mo', 'Di', 'Mi', 'Do', 'Fr', 'Sa', 'So'],
    'hour': 'h',
    'minute': 'm',
    'second': 's'
  }
};

Map<String, dynamic> i18nObjInLanguage(String language) {
  if(language == null || language.isEmpty) return i18nModel['en'];
  return i18nModel[language] ?? i18nModel['en'];
}

String i18nObjInLanguageLookup(String language, String key, int index){
  final i18n = i18nObjInLanguage(language);
  final i18nKey = i18n[key] as List<String>;
  return i18nKey[index];
}
